==> nextcloud-26.0.11p1.tgz: nextcloud/apps/notifications/l10n/nb.js <==
OC.L10N.register(
    "notifications",
    {
    "Hello %s" : "Hei %s",
    "Hello %s," : "Hei %s,",
    "_New notification for %s_::_%n new notifications for %s_" : ["Nytt varsel for %s","%n nye varsler for %s"],
    "_You have a new notification for %s_::_You have %n new notifications for %s_" : ["Du har ett nytt varsel for %s","Du har %n nye varsler for %s"],
    "You can change the frequency of these emails or disable them in the <a href=\"%s\">settings</a>." : "Du kan endre hyppigheten på disse e-postene eller deaktivere dem i <a href=\"%s\">innstillinger</a>.",
    "You can change the frequency of these emails or disable them in the settings: %s" : "Du kan endre hyppigheten på disse e-postene eller deaktivere dem i innstillingene: %s",
    "Admin notifications" : "Administrator- notifikasjoner",
    "Notifications" : "Varsel",
    "This app provides a backend and frontend for the notification API available in Nextcloud." : "Denne appen gir en backend og frontend for varslings-APIet som er tilgjengelig i Nextcloud.",
    "This app provides a backend and frontend for the notification API available in Nextcloud.\n\t\tThe API is used by other apps to notify users in the web UI and sync clients about various things. Some examples are:\n\n📬 Federated file sharing: You received a new remote share\n\n📑 Comments: Another user mentioned you in a comment on a file\n\n🚢 Update notification: Available update for an app or nextcloud itself\n\n📣 Announcement center: An announcement was posted by an admin" : "Denne appen gir en backend og frontend for varslings-API-et som er tilgjengelig i Nextcloud.\n\t\tAPI-et brukes av andre apper for å varsle brukere i webgrensesnittet og synk-klienter om forskjellige ting. Noen eksempler er:\n\n📬 Federert fildeling: Du mottok en ny ekstern deling\n\n📑 Kommentarer: En annen bruker nevnte deg i en kommentar til en fil\n\n🚢 Oppdateringsvarsel: Tilgjengelig oppdatering for en app eller selve nextcloud\n\n📣 Kunngjøringssenter: En kunngjøring ble lagt ut av en admin",
    "Failed to perform action" : "Klarte ikke å utføre handling",
    "Dismiss" : "Avvis",
    "Contact Nextcloud GmbH" : "Kontakt Nextcloud GmbH",
    "seconds ago" : "sekunder siden",
    "Failed to dismiss notification" : "Klarte ikke avvise varsel",
    "in {path}" : "i {path}",
    "Dismiss all notifications" : "Avvis alle varsler",
    "Requesting browser permissions to show notifications" : "Ber om nettlesertillatelser for å vise varsler",
    "Push notifications might be unreliable" : "Push-varsler kan være upålitelige",
    "No notifications" : "Ingen varsel",
    "Nextcloud GmbH sponsors a free push notification gateway for private users. To ensure good service, the gateway limits the number of push notifications per server. For enterprise users, a more scalable gateway is available. Contact Nextcloud GmbH for more information." : "Nextcloud GmbH sponser en gratis push-varslingsgateway for private brukere. For å sikre god service begrenser gatewayen antall push-varsler per server. For bedriftsbrukere er en mer skalerbar gateway tilgjengelig. Kontakt Nextcloud GmbH for mer informasjon.",
    "Failed to dismiss all notifications" : "Klarte ikke å avvise alle varslene",
    "Notifications defaults" : "Standardinnstillinger for varsler",
    "Configure the default notification settings for new users" : "Konfigurer standard varslingsinnstillinger for nye brukere",
    "Send email reminders about unhandled notifications after:" : "Send e-postpåminnelser om ubehandlede varsler etter:",
    "Play sound when a new notification arrives" : "Spill av lyd når et nytt varsel kommer",
    "Play sound when a call started (requires Nextcloud Talk)" : "Spill av lyd når en samtale startet (krever Nextcloud Talk)",
    "Never" : "Aldri",
    "1 hour" : "1 time",
    "3 hours" : "3 timer",
    "1 day" : "1 dag",
    "1 week" : "1 uke",
    "Your settings have been updated." : "Innstillingene dine ble oppdatert.",
    "An error occurred while updating your settings." : "Det oppstod en feil under oppdatering av innstillingene.",
    "You need to set up your email address before you can receive notification emails." : "Du må sette opp e-postadressen din før du kan motta varslinger på e-post."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-27.1.11.tgz: nextcloud/apps/notifications/l10n/nb.js <==
OC.L10N.register(
    "notifications",
    {
    "Hello %s" : "Hei %s",
    "Hello %s," : "Hei %s,",
    "_New notification for %s_::_%n new notifications for %s_" : ["Nytt varsel for %s","%n nye varsler for %s"],
    "_You have a new notification for %s_::_You have %n new notifications for %s_" : ["Du har ett nytt varsel for %s","Du har %n nye varsler for %s"],
    "You can change the frequency of these emails or disable them in the <a href=\"%s\">settings</a>." : "Du kan endre hyppigheten på disse e-postene eller deaktivere dem i <a href=\"%s\">innstillinger</a>.",
    "You can change the frequency of these emails or disable them in the settings: %s" : "Du kan endre hyppigheten på disse e-postene eller deaktivere dem i innstillingene: %s",
    "Admin notifications" : "Administrator- notifikasjoner",
    "Notifications" : "Varsel",
    "Push notifications - Fair use policy" : "Push-varsler – Retningslinjer for rimelig bruk",
    "Nextcloud GmbH sponsors a free push notification gateway for private users. To ensure good service, the gateway limits the number of push notifications per server and the limit was reached for this server. For enterprise users, a more scalable gateway is available." : "Nextcloud GmbH sponser en gratis push-varslingsgateway for private brukere. For å sikre god service begrenser gatewayen antall push-varsler per server, og grensen ble nådd for denne serveren. For bedriftsbrukere er en mer skalerbar gateway tilgjengelig.",
    "This app provides a backend and frontend for the notification API available in Nextcloud." : "Denne appen gir en backend og frontend for varslings-APIet som er tilgjengelig i Nextcloud.",
    "This app provides a backend and frontend for the notification API available in Nextcloud.\n\t\tThe API is used by other apps to notify users in the web UI and sync clients about various things. Some examples are:\n\n📬 Federated file sharing: You received a new remote share\n\n📑 Comments: Another user mentioned you in a comment on a file\n\n🚢 Update notification: Available update for an app or nextcloud itself\n\n📣 Announcement center: An announcement was posted by an admin" : "Denne appen gir en backend og frontend for varslings-API-et som er tilgjengelig i Nextcloud.\n\t\tAPI-et brukes av andre apper for å varsle brukere i webgrensesnittet og synk-klienter om forskjellige ting. Noen eksempler er:\n\n📬 Federert fildeling: Du mottok en ny ekstern deling\n\n📑 Kommentarer: En annen bruker nevnte deg i en kommentar til en fil\n\n🚢 Oppdateringsvarsel: Tilgjengelig oppdatering for en app eller selve nextcloud\n\n📣 Kunngjøringssenter: En kunngjøring ble lagt ut av en admin",
    "Failed to perform action" : "Klarte ikke å utføre handling",
    "Dismiss" : "Avvis",
    "Contact Nextcloud GmbH" : "Kontakt Nextcloud GmbH",
    "seconds ago" : "sekunder siden",
    "Failed to dismiss notification" : "Klarte ikke avvise varsel",
    "in {path}" : "i {path}",
    "Dismiss all notifications" : "Avvis alle varsler",
    "Requesting browser permissions to show notifications" : "Ber om nettlesertillatelser for å vise varsler",
    "Push notifications might be unreliable" : "Push-varsler kan være upålitelige",
    "No notifications" : "Ingen varsel",
    "Nextcloud GmbH sponsors a free push notification gateway for private users. To ensure good service, the gateway limits the number of push notifications per server. For enterprise users, a more scalable gateway is available. Contact Nextcloud GmbH for more information." : "Nextcloud GmbH sponser en gratis push-varslingsgateway for private brukere. For å sikre god service begrenser gatewayen antall push-varsler per server. For bedriftsbrukere er en mer skalerbar gateway tilgjengelig. Kontakt Nextcloud GmbH for mer informasjon.",
    "Failed to dismiss all notifications" : "Klarte ikke å avvise alle varslene",
    "Notifications defaults" : "Standardinnstillinger for varsler",
    "Configure the default notification settings for new users" : "Konfigurer standard varslingsinnstillinger for nye brukere",
    "Send email reminders about unhandled notifications after:" : "Send e-postpåminnelser om ubehandlede varsler etter:",
    "Play sound when a new notification arrives" : "Spill av lyd når et nytt varsel kommer",
    "Play sound when a call started (requires Nextcloud Talk)" : "Spill av lyd når en samtale startet (krever Nextcloud Talk)",
    "Never" : "Aldri",
    "1 hour" : "1 time",
    "3 hours" : "3 timer",
    "1 day" : "1 dag",
    "1 week" : "1 uke",
    "Your settings have been updated." : "Innstillingene dine ble oppdatert.",
    "An error occurred while updating your settings." : "Det oppstod en feil under oppdatering av innstillingene.",
    "You need to set up your email address before you can receive notification emails." : "Du må sette opp e-postadressen din før du kan motta varslinger på e-post."
},
"nplurals=2; plural=(n != 1);");
